@@ -38,8 +38,8 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x040702
-pyqt_version_str = "4.7.2"
+pyqt_version = 0x040703
+pyqt_version_str = "4.7.3"
 
 sip_min_version = 0x040a00
 
@@ -1069,7 +1069,10 @@ def run_command(cmd):
     lout = fout.readline()
     while lout:
         if opts.verbose:
-            sys.stdout.write(str(lout))
+            if sys.hexversion >= 0x03000000:
+                sys.stdout.write(str(lout, encoding=sys.stdout.encoding))
+            else:
+                sys.stdout.write(lout)
 
         lout = fout.readline()
 
