@@ -1,38 +1,43 @@
 #!/usr/bin/env python
 
-"""***************************************************************************
-**
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
-**
-** This file is part of the example classes of the Qt Toolkit.
-**
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
-**
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-***************************************************************************"""
+############################################################################
+##
+## Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+##
+## This file is part of the example classes of the Qt Toolkit.
+##
+## This file may be used under the terms of the GNU General Public
+## License version 2.0 as published by the Free Software Foundation
+## and appearing in the file LICENSE.GPL included in the packaging of
+## this file.  Please review the following information to ensure GNU
+## General Public Licensing requirements will be met:
+## http://www.trolltech.com/products/qt/opensource.html
+##
+## If you are unsure which license is appropriate for your use, please
+## review the following information:
+## http://www.trolltech.com/products/qt/licensing.html or contact the
+## sales department at sales@trolltech.com.
+##
+## This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+## WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+##
+############################################################################
+
+# This is only needed for Python v2 but is harmless for Python v3.
+import sip
+sip.setapi('QString', 2)
+sip.setapi('QVariant', 2)
 
-import sys
 import math
+
 from PyQt4 import QtCore, QtGui
 
 import chart_rc
 
 
 class PieView(QtGui.QAbstractItemView):
-    def __init__(self, parent = None):
-        QtGui.QAbstractItemView.__init__(self, parent)
+    def __init__(self, parent=None):
+        super(PieView, self).__init__(parent)
 
         self.horizontalScrollBar().setRange(0, 0)
         self.verticalScrollBar().setRange(0, 0)
@@ -42,10 +47,11 @@ class PieView(QtGui.QAbstractItemView):
         self.pieSize = self.totalSize - 2*self.margin
         self.validItems = 0
         self.totalValue = 0.0
-        self.selectionRect = None
+        self.origin = QtCore.QPoint()
+        self.rubberBand = None
 
     def dataChanged(self, topLeft, bottomRight):
-        QtGui.QAbstractItemView.dataChanged(self, topLeft, bottomRight)
+        super(PieView, self).dataChanged(topLeft, bottomRight)
 
         self.validItems = 0
         self.totalValue = 0.0
@@ -53,9 +59,9 @@ class PieView(QtGui.QAbstractItemView):
         for row in range(self.model().rowCount(self.rootIndex())):
 
             index = self.model().index(row, 1, self.rootIndex())
-            value, ok = self.model().data(index).toDouble()
+            value = self.model().data(index)
 
-            if value > 0.0:
+            if value is not None and value > 0.0:
                 self.totalValue += value
                 self.validItems += 1
 
@@ -63,13 +69,11 @@ class PieView(QtGui.QAbstractItemView):
 
     def edit(self, index, trigger, event):
         if index.column() == 0:
-            return QtGui.QAbstractItemView.edit(self, index, trigger, event)
+            return super(PieView, self).edit(index, trigger, event)
         else:
             return False
 
     def indexAt(self, point):
-        """Returns the item that covers the coordinate given in the view.
-        """
         if self.validItems == 0:
             return QtCore.QModelIndex()
 
@@ -98,7 +102,7 @@ class PieView(QtGui.QAbstractItemView):
             for row in range(self.model().rowCount(self.rootIndex())):
 
                 index = self.model().index(row, 1, self.rootIndex())
-                value, ok = self.model().data(index).toDouble()
+                value = self.model().data(index)
 
                 if value > 0.0:
                     sliceAngle = 360*value/self.totalValue
@@ -109,7 +113,6 @@ class PieView(QtGui.QAbstractItemView):
                     startAngle += sliceAngle
 
         else:
-
             itemHeight = QtGui.QFontMetrics(self.viewOptions().font).height()
             listItem = int((wy - self.margin) / itemHeight)
             validRow = 0
@@ -117,12 +120,13 @@ class PieView(QtGui.QAbstractItemView):
             for row in range(self.model().rowCount(self.rootIndex())):
 
                 index = self.model().index(row, 1, self.rootIndex())
-                if self.model().data(index).toDouble()[0] > 0.0:
+                if self.model().data(index) > 0.0:
 
                     if listItem == validRow:
                         return self.model().index(row, 0, self.rootIndex())
 
-                    # Update the list index that corresponds to the next valid row.
+                    # Update the list index that corresponds to the next valid
+                    # row.
                     validRow += 1
 
         return QtCore.QModelIndex()
@@ -131,9 +135,6 @@ class PieView(QtGui.QAbstractItemView):
         return False
 
     def itemRect(self, index):
-        """Returns the rectangle of the item at position \a index in the
-           model. The rectangle is in contents coordinates.
-        """
         if not index.isValid():
             return QtCore.QRect()
 
@@ -145,11 +146,11 @@ class PieView(QtGui.QAbstractItemView):
         else:
             valueIndex = index
 
-        if self.model().data(valueIndex).toDouble()[0] > 0.0:
+        if self.model().data(valueIndex) > 0.0:
 
             listItem = 0
             for row in range(index.row()-1, -1, -1):
-                if self.model().data(self.model().index(row, 1, self.rootIndex())).toDouble()[0] > 0.0:
+                if self.model().data(self.model().index(row, 1, self.rootIndex())) > 0.0:
                     listItem += 1
 
             if index.column() == 0:
@@ -170,14 +171,14 @@ class PieView(QtGui.QAbstractItemView):
         if index.column() != 1:
             return QtGui.QRegion(self.itemRect(index))
 
-        if self.model().data(index).toDouble()[0] <= 0.0:
+        if self.model().data(index) <= 0.0:
             return QtGui.QRegion()
 
         startAngle = 0.0
         for row in range(self.model().rowCount(self.rootIndex())):
 
             sliceIndex = self.model().index(row, 1, self.rootIndex())
-            value, ok = self.model().data(sliceIndex).toDouble()
+            value = self.model().data(sliceIndex)
 
             if value > 0.0:
                 angle = 360*value/self.totalValue
@@ -185,8 +186,9 @@ class PieView(QtGui.QAbstractItemView):
                 if sliceIndex == index:
                     slicePath = QtGui.QPainterPath()
                     slicePath.moveTo(self.totalSize/2, self.totalSize/2)
-                    slicePath.arcTo(self.margin, self.margin, self.margin+self.pieSize, self.margin+self.pieSize,
-                                    startAngle, angle)
+                    slicePath.arcTo(self.margin, self.margin,
+                            self.margin+self.pieSize, self.margin+self.pieSize,
+                            startAngle, angle)
                     slicePath.closeSubpath()
 
                     return QtGui.QRegion(slicePath.toFillPolygon().toPolygon())
@@ -198,9 +200,28 @@ class PieView(QtGui.QAbstractItemView):
     def horizontalOffset(self):
         return self.horizontalScrollBar().value()
 
+    def mousePressEvent(self, event):
+        super(PieView, self).mousePressEvent(event)
+
+        self.origin = event.pos()
+        if not self.rubberBand:
+            self.rubberBand = QtGui.QRubberBand(QtGui.QRubberBand.Rectangle,
+                    self)
+        self.rubberBand.setGeometry(QtCore.QRect(self.origin, QtCore.QSize()))
+        self.rubberBand.show()
+
+    def mouseMoveEvent(self, event):
+        if self.rubberBand:
+            self.rubberBand.setGeometry(QtCore.QRect(self.origin, event.pos()).normalized())
+
+        super(PieView, self).mouseMoveEvent(event)
+
     def mouseReleaseEvent(self, event):
-        QtGui.QAbstractItemView.mouseReleaseEvent(self, event)
-        self.selectionRect = None
+        super(PieView, self).mouseReleaseEvent(event)
+
+        if self.rubberBand:
+            self.rubberBand.hide()
+
         self.viewport().update()
 
     def moveCursor(self, cursorAction, modifiers):
@@ -210,20 +231,21 @@ class PieView(QtGui.QAbstractItemView):
            cursorAction == QtGui.QAbstractItemView.MoveUp:
 
             if current.row() > 0:
-                current = self.model().index(current.row() - 1, current.column(),
-                                         self.rootIndex())
+                current = self.model().index(current.row() - 1,
+                        current.column(), self.rootIndex())
             else:
-                current = self.model().index(0, current.column(), self.rootIndex())
+                current = self.model().index(0, current.column(),
+                        self.rootIndex())
 
         elif cursorAction == QtGui.QAbstractItemView.MoveRight or \
              cursorAction == QtGui.QAbstractItemView.MoveDown:
 
             if current.row() < rows(current) - 1:
-                current = self.model().index(current.row() + 1, current.column(),
-                                             self.rootIndex())
+                current = self.model().index(current.row() + 1,
+                        current.column(), self.rootIndex())
             else:
-                current = self.model().index(rows(current) - 1, current.column(),
-                                             self.rootIndex())
+                current = self.model().index(rows(current) - 1,
+                        current.column(), self.rootIndex())
 
         self.viewport().update()
         return current
@@ -234,50 +256,52 @@ class PieView(QtGui.QAbstractItemView):
         state = option.state
 
         background = option.palette.base()
-        foreground = QtGui.QPen(option.palette.color(QtGui.QPalette.Foreground))
+        foreground = QtGui.QPen(option.palette.color(QtGui.QPalette.WindowText))
         textPen = QtGui.QPen(option.palette.color(QtGui.QPalette.Text))
         highlightedPen = QtGui.QPen(option.palette.color(QtGui.QPalette.HighlightedText))
 
-        painter = QtGui.QPainter()
-        painter.begin(self.viewport())
+        painter = QtGui.QPainter(self.viewport())
         painter.setRenderHint(QtGui.QPainter.Antialiasing)
 
         painter.fillRect(event.rect(), background)
         painter.setPen(foreground)
 
         # Viewport rectangles
-        pieRect = QtCore.QRect(self.margin, self.margin, self.pieSize, self.pieSize)
+        pieRect = QtCore.QRect(self.margin, self.margin, self.pieSize,
+                self.pieSize)
         keyPoint = QtCore.QPoint(self.totalSize - self.horizontalScrollBar().value(),
-                          self.margin - self.verticalScrollBar().value())
+                self.margin - self.verticalScrollBar().value())
 
         if self.validItems > 0:
             painter.save()
             painter.translate(pieRect.x() - self.horizontalScrollBar().value(),
-                              pieRect.y() - self.verticalScrollBar().value())
+                    pieRect.y() - self.verticalScrollBar().value())
             painter.drawEllipse(0, 0, self.pieSize, self.pieSize)
             startAngle = 0.0
 
             for row in range(self.model().rowCount(self.rootIndex())):
 
                 index = self.model().index(row, 1, self.rootIndex())
-                value, ok = self.model().data(index).toDouble()
+                value = self.model().data(index)
 
                 if value > 0.0:
                     angle = 360*value/self.totalValue
 
                     colorIndex = self.model().index(row, 0, self.rootIndex())
-                    color = QtGui.QColor(self.model().data(colorIndex,
-                                   QtCore.Qt.DecorationRole).toString())
+                    color = self.model().data(colorIndex,
+                            QtCore.Qt.DecorationRole)
 
                     if self.currentIndex() == index:
-                        painter.setBrush(QtGui.QBrush(color, QtCore.Qt.Dense4Pattern))
+                        painter.setBrush(QtGui.QBrush(color,
+                                QtCore.Qt.Dense4Pattern))
                     elif selections.isSelected(index):
-                        painter.setBrush(QtGui.QBrush(color, QtCore.Qt.Dense3Pattern))
+                        painter.setBrush(QtGui.QBrush(color,
+                                QtCore.Qt.Dense3Pattern))
                     else:
                         painter.setBrush(QtGui.QBrush(color))
 
-                    painter.drawPie(0, 0, self.pieSize, self.pieSize, int(startAngle*16),
-                                    int(angle*16))
+                    painter.drawPie(0, 0, self.pieSize, self.pieSize,
+                            int(startAngle*16), int(angle*16))
 
                     startAngle += angle
 
@@ -287,7 +311,7 @@ class PieView(QtGui.QAbstractItemView):
 
             for row in range(self.model().rowCount(self.rootIndex())):
                 index = self.model().index(row, 1, self.rootIndex())
-                value, ok = self.model().data(index).toDouble()
+                value = self.model().data(index)
 
                 if value > 0.0:
                     labelIndex = self.model().index(row, 0, self.rootIndex())
@@ -302,16 +326,6 @@ class PieView(QtGui.QAbstractItemView):
 
                     keyNumber += 1
 
-        if self.selectionRect:
-            band = QtGui.QStyleOptionRubberBand()
-            band.shape = QtGui.QRubberBand.Rectangle
-            band.rect = self.selectionRect
-            painter.save()
-            self.style().drawControl(QtGui.QStyle.CE_RubberBand, band, painter)
-            painter.restore()
-
-        painter.end()
-
     def resizeEvent(self, event):
         self.updateGeometries()
 
@@ -321,23 +335,24 @@ class PieView(QtGui.QAbstractItemView):
     def rowsInserted(self, parent, start, end):
         for row in range(start, end + 1):
             index = self.model().index(row, 1, self.rootIndex())
-            value, ok = self.model().data(index).toDouble()
+            value = self.model().data(index)
 
-            if value > 0.0:
+            if value is not None and value > 0.0:
                 self.totalValue += value
                 self.validItems += 1
 
-        QtGui.QAbstractItemView.rowsInserted(self, parent, start, end)
+        super(PieView, self).rowsInserted(parent, start, end)
 
     def rowsAboutToBeRemoved(self, parent, start, end):
         for row in range(start, end + 1):
             index = self.model().index(row, 1, self.rootIndex())
-            value, ok = self.model().data(index).toDouble()
-            if value > 0.0:
+            value = self.model().data(index)
+
+            if value is not None and value > 0.0:
                 self.totalValue -= value
                 self.validItems -= 1
 
-        QtGui.QAbstractItemView.rowsAboutToBeRemoved(self, parent, start, end)
+        super(PieView, self).rowsAboutToBeRemoved(parent, start, end)
 
     def scrollContentsBy(self, dx, dy):
         self.viewport().scroll(dx, dy)
@@ -363,13 +378,11 @@ class PieView(QtGui.QAbstractItemView):
                     rect.bottom() - area.bottom(), rect.top() - area.top()))
 
     def setSelection(self, rect, command):
-        """Find the indices corresponding to the extent of the selection.
-        """
         # Use content widget coordinates because we will use the itemRegion()
         # function to check for intersections.
 
         contentsRect = rect.translated(self.horizontalScrollBar().value(),
-                                       self.verticalScrollBar().value())
+                self.verticalScrollBar().value()).normalized()
 
         rows = self.model().rowCount(self.rootIndex())
         columns = self.model().columnCount(self.rootIndex())
@@ -403,7 +416,6 @@ class PieView(QtGui.QAbstractItemView):
             selection = QtGui.QItemSelection(noIndex, noIndex)
             self.selectionModel().select(selection, command)
 
-        self.selectionRect = QtCore.QRect(rect)
         self.update()
 
     def updateGeometries(self):
@@ -416,8 +428,6 @@ class PieView(QtGui.QAbstractItemView):
         return self.verticalScrollBar().value()
 
     def visualRect(self, index):
-        """Returns the position of the item in viewport coordinates.
-        """
         rect = self.itemRect(index)
         if rect.isValid():
             return QtCore.QRect(rect.left() - self.horizontalScrollBar().value(),
@@ -427,64 +437,48 @@ class PieView(QtGui.QAbstractItemView):
             return rect
 
     def visualRegionForSelection(self, selection):
-        """Returns a region corresponding to the selection in viewport coordinates.
-        """
-        ranges = len(selection)
+        region = QtGui.QRegion()
 
-        if ranges == 0:
-            return QtGui.QRegion()
+        for span in selection:
+            for row in range(span.top(), span.bottom() + 1):
+                for col in range(span.left(), span.right() + 1):
+                    index = self.model().index(row, col, self.rootIndex())
+                    region += self.visualRect(index)
 
-        # Note that we use the top and bottom functions of the selection range
-        # since the data is stored in rows.
-
-        firstRow = selection[0].top()
-        lastRow = selection[0].top()
-
-        for i in range(ranges):
-            firstRow = min(firstRow, selection[i].top())
-            lastRow = max(lastRow, selection[i].bottom())
-
-        firstItem = self.model().index(min(firstRow, lastRow), 0, self.rootIndex())
-        lastItem = self.model().index(max(firstRow, lastRow), 0, self.rootIndex())
-
-        firstRect = self.visualRect(firstItem)
-        lastRect = self.visualRect(lastItem)
-
-        return QtGui.QRegion(firstRect.unite(lastRect))
+        return region
 
 
 class MainWindow(QtGui.QMainWindow):
-    def __init__(self, parent=None):
-        QtGui.QMainWindow.__init__(self, parent)
+    def __init__(self):
+        super(MainWindow, self).__init__()
 
-        fileMenu = QtGui.QMenu(self.tr("&File"), self)
-        openAction = fileMenu.addAction(self.tr("&Open..."))
-        openAction.setShortcut(QtGui.QKeySequence(self.tr("Ctrl+O")))
-        saveAction = fileMenu.addAction(self.tr("&Save As..."))
-        saveAction.setShortcut(QtGui.QKeySequence(self.tr("Ctrl+S")))
-        quitAction = fileMenu.addAction(self.tr("E&xit"))
-        quitAction.setShortcut(QtGui.QKeySequence(self.tr("Ctrl+Q")))
+        fileMenu = QtGui.QMenu("&File", self)
+        openAction = fileMenu.addAction("&Open...")
+        openAction.setShortcut("Ctrl+O")
+        saveAction = fileMenu.addAction("&Save As...")
+        saveAction.setShortcut("Ctrl+S")
+        quitAction = fileMenu.addAction("E&xit")
+        quitAction.setShortcut("Ctrl+Q")
 
         self.setupModel()
         self.setupViews()
 
-        self.connect(openAction, QtCore.SIGNAL("triggered()"), self.openFile)
-        self.connect(saveAction, QtCore.SIGNAL("triggered()"), self.saveFile)
-        self.connect(quitAction, QtCore.SIGNAL("triggered()"),
-                     QtGui.qApp, QtCore.SLOT("quit()"))
+        openAction.triggered.connect(self.openFile)
+        saveAction.triggered.connect(self.saveFile)
+        quitAction.triggered.connect(QtGui.qApp.quit)
 
         self.menuBar().addMenu(fileMenu)
         self.statusBar()
 
-        self.openFile(QtCore.QString(":/Charts/qtdata.cht"))
+        self.openFile(':/Charts/qtdata.cht')
 
-        self.setWindowTitle(self.tr("Chart"))
-        self.resize(640, 480)
+        self.setWindowTitle("Chart")
+        self.resize(870, 550)
 
     def setupModel(self):
         self.model = QtGui.QStandardItemModel(8, 2, self)
-        self.model.setHeaderData(0, QtCore.Qt.Horizontal, QtCore.QVariant(self.tr("Label")))
-        self.model.setHeaderData(1, QtCore.Qt.Horizontal, QtCore.QVariant(self.tr("Quantity")))
+        self.model.setHeaderData(0, QtCore.Qt.Horizontal, "Label")
+        self.model.setHeaderData(1, QtCore.Qt.Horizontal, "Quantity")
 
     def setupViews(self):
         splitter = QtGui.QSplitter()
@@ -502,71 +496,74 @@ class MainWindow(QtGui.QMainWindow):
         table.setSelectionModel(self.selectionModel)
         self.pieChart.setSelectionModel(self.selectionModel)
 
+        table.horizontalHeader().setStretchLastSection(True)
+
         self.setCentralWidget(splitter)
 
-    def openFile(self, path = QtCore.QString()):
-        if path.isNull():
-            fileName = QtGui.QFileDialog.getOpenFileName(self, self.tr("Choose a data file"),
-                                                    "", "*.cht")
-        else:
-            fileName = path
+    def openFile(self, path=None):
+        if not path:
+            path = QtGui.QFileDialog.getOpenFileName(self,
+                    "Choose a data file", '', '*.cht')
 
-        if not fileName.isEmpty():
-            f = QtCore.QFile(fileName)
+        if path:
+            f = QtCore.QFile(path)
 
             if f.open(QtCore.QFile.ReadOnly | QtCore.QFile.Text):
                 stream = QtCore.QTextStream(f)
 
-                self.model.removeRows(0, self.model.rowCount(QtCore.QModelIndex()),
-                                      QtCore.QModelIndex())
+                self.model.removeRows(0,
+                        self.model.rowCount(QtCore.QModelIndex()),
+                        QtCore.QModelIndex())
 
                 row = 0
-                while True:
+                line = stream.readLine()
+                while line:
+                    self.model.insertRows(row, 1, QtCore.QModelIndex())
+
+                    pieces = line.split(',')
+                    self.model.setData(self.model.index(row, 0, QtCore.QModelIndex()),
+                                pieces[0])
+                    self.model.setData(self.model.index(row, 1, QtCore.QModelIndex()),
+                                float(pieces[1]))
+                    self.model.setData(self.model.index(row, 0, QtCore.QModelIndex()),
+                                QtGui.QColor(pieces[2]),
+                                QtCore.Qt.DecorationRole)
+
+                    row += 1
                     line = stream.readLine()
-                    if not line.isEmpty():
-                        self.model.insertRows(row, 1, QtCore.QModelIndex())
-
-                        pieces = line.split(",", QtCore.QString.SkipEmptyParts)
-                        self.model.setData(self.model.index(row, 0, QtCore.QModelIndex()),
-                                           QtCore.QVariant(pieces[0]))
-                        self.model.setData(self.model.index(row, 1, QtCore.QModelIndex()),
-                                           QtCore.QVariant(pieces[1]))
-                        self.model.setData(self.model.index(row, 0, QtCore.QModelIndex()),
-                                           QtCore.QVariant(QtCore.QString(pieces[2])), QtCore.Qt.DecorationRole)
-                        row += 1
-
-                    if line.isEmpty():
-                        break
 
                 f.close()
-                self.statusBar().showMessage(self.tr("Loaded %1").arg(fileName), 2000)
+                self.statusBar().showMessage("Loaded %s" % path, 2000)
 
     def saveFile(self):
-        fileName = QtGui.QFileDialog.getSaveFileName(self,
-            self.tr("Save file as"), "", "*.cht")
+        fileName = QtGui.QFileDialog.getSaveFileName(self, "Save file as", '',
+                '*.cht')
 
-        if not fileName.isEmpty():
+        if fileName:
             f = QtCore.QFile(fileName)
 
             if f.open(QtCore.QFile.WriteOnly | QtCore.QFile.Text):
                 for row in range(self.model.rowCount(QtCore.QModelIndex())):
-                    pieces = QtCore.QStringList()
+                    pieces = []
 
                     pieces.append(self.model.data(self.model.index(row, 0, QtCore.QModelIndex()),
-                                                  QtCore.Qt.DisplayRole).toString())
-                    pieces.append(self.model.data(self.model.index(row, 1, QtCore.QModelIndex()),
-                                                  QtCore.Qt.DisplayRole).toString())
+                            QtCore.Qt.DisplayRole))
+                    pieces.append(str(self.model.data(self.model.index(row, 1, QtCore.QModelIndex()),
+                            QtCore.Qt.DisplayRole)))
                     pieces.append(self.model.data(self.model.index(row, 0, QtCore.QModelIndex()),
-                                                  QtCore.Qt.DecorationRole).toString())
+                            QtCore.Qt.DecorationRole).name())
 
-                    f.write(QtCore.QByteArray(str(pieces.join(","))))
-                    f.write("\n")
+                    f.write(QtCore.QByteArray(','.join(pieces)))
+                    f.write('\n')
 
             f.close()
-            self.statusBar().showMessage(self.tr("Saved %1").arg(fileName), 2000)
+            self.statusBar().showMessage("Saved %s" % fileName, 2000)
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
+
+    import sys
+
     app = QtGui.QApplication(sys.argv)
     window = MainWindow()
     window.show()
