@@ -124,6 +124,7 @@ class UIParser(object):
         self.actions = []
         self.currentActionGroup = None
         self.resources = []
+        self.button_groups = []
 
     def setupObject(self, clsname, parent, branch, is_attribute = True):
         name = self.uniqueName(branch.attrib.get("name") or clsname[1:].lower())
@@ -177,6 +178,22 @@ class UIParser(object):
             self.handleHeaderView(elem, "verticalHeader",
                     widget.verticalHeader())
 
+        elif isinstance(widget, QtGui.QAbstractButton):
+            bg_i18n = self.wprops.getAttribute(elem, "buttonGroup")
+            if bg_i18n is not None:
+                bg_name = bg_i18n.string
+
+                for bg in self.button_groups:
+                    if bg.objectName() == bg_name:
+                        break
+                else:
+                    bg = self.factory.createQObject("QButtonGroup", bg_name,
+                            (self.toplevelWidget, ))
+                    bg.setObjectName(bg_name)
+                    self.button_groups.append(bg)
+
+                bg.addButton(widget)
+
         if self.sorting_enabled is not None:
             widget.setSortingEnabled(self.sorting_enabled)
             self.sorting_enabled = None
@@ -237,7 +254,7 @@ class UIParser(object):
                 if tbArea is None:
                     topwidget.addToolBar(widget)
                 else:
-                    if isinstance(tbArea, basestring):
+                    if isinstance(tbArea, str):
                         tbArea = getattr(QtCore.Qt, tbArea)
                     else:
                         tbArea = QtCore.Qt.ToolBarArea(tbArea)
@@ -281,7 +298,7 @@ class UIParser(object):
 
         value = self.wprops.getAttribute(elem, name + "ShowSortIndicator")
         if value is not None:
-            header.setShowSortIndicator(value)
+            header.setSortIndicatorShown(value)
 
         value = self.wprops.getAttribute(elem, name + "StretchLastSection")
         if value is not None:
@@ -291,14 +308,12 @@ class UIParser(object):
         width = int(elem.findtext("property/size/width"))
         height = int(elem.findtext("property/size/height"))
 
-        sizeType = self.wprops.getProperty(elem, "sizeType")
-        if sizeType is None:
-            sizeType = "QSizePolicy::Expanding"
+        sizeType = self.wprops.getProperty(elem, "sizeType",
+                QtGui.QSizePolicy.Expanding)
 
-        policy = (QtGui.QSizePolicy.Minimum,
-                  getattr(QtGui.QSizePolicy, sizeType.split("::")[-1]))
+        policy = (QtGui.QSizePolicy.Minimum, sizeType)
 
-        if self.wprops.getProperty(elem, "orientation") == "Qt::Horizontal":
+        if self.wprops.getProperty(elem, "orientation") == QtCore.Qt.Horizontal:
             policy = policy[1], policy[0]
 
         spacer = self.factory.createQObject("QSpacerItem",
@@ -441,8 +456,10 @@ class UIParser(object):
             elif isinstance(w, QtGui.QListWidget):
                 text = self.wprops.getProperty(elem, "text")
                 icon = self.wprops.getProperty(elem, "icon")
+                flags = self.wprops.getProperty(elem, "flags")
+                check_state = self.wprops.getProperty(elem, "checkState")
 
-                if icon:
+                if icon or flags or check_state:
                     item_name = "item"
                 else:
                     item_name = None
@@ -460,6 +477,12 @@ class UIParser(object):
                 if icon:
                     item.setIcon(icon)
 
+                if flags:
+                    item.setFlags(flags)
+
+                if check_state:
+                    item.setCheckState(check_state)
+
             elif isinstance(w, QtGui.QTreeWidget):
                 if self.itemstack:
                     parent, _ = self.itemstack[-1]
@@ -487,13 +510,18 @@ class UIParser(object):
                 column = -1
                 for prop in elem.findall("property"):
                     c_prop = self.wprops.convert(prop)
+                    c_prop_name = prop.attrib["name"]
 
-                    if prop.attrib["name"] == "text":
+                    if c_prop_name == "text":
                         column += 1
                         if c_prop:
                             titm.setText(column, c_prop)
-                    elif c_prop:
+                    elif c_prop_name == "icon":
                         item.setIcon(column, c_prop)
+                    elif c_prop_name == "flags":
+                        item.setFlags(c_prop)
+                    elif c_prop_name == "checkState":
+                        item.setCheckState(column, c_prop)
 
                 self.traverseWidgetTree(elem)
                 _, self.item_nr = self.itemstack.pop()
@@ -501,6 +529,8 @@ class UIParser(object):
             elif isinstance(w, QtGui.QTableWidget):
                 text = self.wprops.getProperty(elem, "text")
                 icon = self.wprops.getProperty(elem, "icon")
+                flags = self.wprops.getProperty(elem, "flags")
+                check_state = self.wprops.getProperty(elem, "checkState")
 
                 item = self.factory.createQObject("QTableWidgetItem", "item",
                         (), False)
@@ -518,6 +548,12 @@ class UIParser(object):
                 if icon:
                     item.setIcon(icon)
 
+                if flags:
+                    item.setFlags(flags)
+
+                if check_state:
+                    item.setCheckState(check_state)
+
                 w.setItem(row, col, item)
 
             self.item_nr += 1
